#!/usr/bin/env python
# -*- coding: utf8 -*-




import numpy as np
import matplotlib.pyplot as plt
import matplotlib as mpl
import equations as eq
import measure as me
from mpl_toolkits.mplot3d import Axes3D



######################################################################################################################################################
# Model parameters and forcing

DT0 = 20						# Amplitude of the forcing temperature (in K)


T = 501							# Temporal discretization (choose an odd number for order 2 scheme)
t = np.arange(0.0,T,1.0)/T
T01 = 290 + 10*np.sin(2*np.pi*t)			# Forcing temperature in box 1 (in K)	
T02 = 310 + 3*np.sin(2*np.pi*t + 0.25*np.pi)	# Forcing temperature in box 2 (in K)	
N_iter = 20						# Maximum number of iterations for the Newton's method
prec = 1e-9						# Precision (stop criterion)


# Adimensional quantities ############################################################################################################################
Nb = 0.1						# Bottom box heating time by conduction / cycle time 
Nr = 0.001						# Atmospheric heating time by radiation / cycle time
Nk = 0.1						# Atmospheric heating time by conduction / cycle time 
######################################################################################################################################################




# We declare the vector (Tu1(1), ..., Tu1(T), Tu2(1), ..., Tu2(T), Tb1(1), ..., Tb1(T), Tb2(1), ..., Tb2(T), beta(1), ..., beta(T)) composed by the 5N variables and the reference vector (profiles at previous iteration)
X = np.block([300*np.ones(4*T), np.zeros(T)])
Xr = X

i=0
err=1.1*prec
while (i < N_iter) & (err>prec):
    A = eq.Homogene(T, Nb, Nr, Nk, T01, T02, Xr)
    B = eq.SecondMember(T, Nr, Nk, T01, T02, Xr)
    X = np.linalg.solve(A,B)
    err = np.sqrt((X-Xr).dot(X-Xr))
    Xr = X.copy()
    i += 1

if i==N_iter:
    print(Nr,Nk,Nb,'No convergence')
else:
    print(Nr,Nk,Nb,'Convergence in',i,'iterations')
	

# Plot different evolution of temperatures
fig = plt.figure()
plt.rc('text', usetex=True)
plt.rc('font', family='serif')


fig1 = plt.subplot(2, 1, 1)
plt.plot(t, T01, 'k-', label=(r'$T_{01}$'),linewidth=1)				# Forcing box 1
plt.plot(t, T02, 'm-', label=(r'$T_{02}$'), linewidth=1)			# Forcing box 2
plt.plot(t, X[0:T], 'r-', label=(r'$T_{a1}$'),linewidth=1)			# Upper box 1
plt.plot(t, X[T:2*T], 'b-', label=(r'$T_{a2}$'), linewidth=1)			# Upper box 2
plt.plot(t, X[2*T:3*T], 'r--',label=(r'$T_{g1}$'), linewidth=1, color='r')	# Bottom box 1
plt.plot(t, X[3*T:4*T], 'b--',label=(r'$T_{g2}$'), linewidth=1, color='b')	# Bottom box 2
plt.ylabel(r'Temperatures ($K$)',fontsize=10)
plt.xlim(0,1)
#plt.ylim(300-15,300+15)
plt.subplots_adjust(top=0.9)
plt.legend(loc="lower left", borderaxespad=0.9)



plt.subplot(2, 1, 2)
q=me.Flux(T, Nr, Nk, T01, Xr)
plt.plot(t, q, 'b-',linewidth=1)								# energy flux
#plt.plot(t, m*(Xr[0:T]-Xr[T:2*T]), 'm-', label=(r'$q$'),linewidth=1)				# Forcing box 1
#plt.plot(t, np.zeros(T), linewidth=1, color='k')
plt.subplots_adjust(top=0.9)
plt.xlabel(r'$t/\tau$',fontsize=10)
plt.ylabel(r'$q~(K)$',fontsize=10)
plt.xlim(0,1)
#plt.ylim(0,2)







filename  = 'figures/Nb='+"{:.3f}".format(Nb)+'_Ng='+"{:.3f}".format(Nr)+'_Nk='+"{:.3f}".format(Nk)+'.eps'
fig.set_size_inches(7.0, 7.0)
plt.savefig(filename, format='eps', dpi=300)


plt.show()

#plt.close(fig)



























